import logging
import os


class Logger(object):
    def __init__(self, name="logger", level=logging.DEBUG):
        FORMAT = "[%(asctime)s] {%(name)s:%(lineno)d} %(levelname)s - %(message)s"

        sh = logging.StreamHandler()
        sh.setFormatter(logging.Formatter(FORMAT))

        os.makedirs("log", exist_ok=True)
        fh = logging.FileHandler("log/%s.log" % name, "a")
        fh.setFormatter(logging.Formatter(FORMAT))

        self.logger = logging.getLogger(name)
        self.logger.setLevel(level)
        while self.logger.hasHandlers():
            self.logger.removeHandler(self.logger.handlers[0])

        self.logger.addHandler(fh)

        self.info("--- --- --- --- Logger is started! --- --- --- ---")

        self.logger.addHandler(sh)

    def debug(self, msg):
        self.logger.debug(msg)

    def info(self, msg):
        self.logger.info(msg)

    def warning(self, msg):
        self.logger.warning(msg)

    def error(self, msg):
        self.logger.error(msg)


if __name__ == "__main__":
    logger = Logger()
    logger.debug("debug")
    logger.info("info")
    logger.warning("warning")
    logger.error("error")



from setuptools import setup, find_packages


if __name__ == "__main__":
    with open("requirements.txt", "r") as f:
        install_requires = map(lambda x: x.strip(), f.readlines())

    with open("README.md", "r") as f:
        long_description = f.read()

    setup(
        name="zmazino",
        version="0.0.6",
        license="MIT",
        author="Khoi Dang Do",
        author_email="mazino2d@gmail.com",
        url="https://github.com/mazino2d/zmazino",
        description="Modern utils library",
        long_description=long_description,
        long_description_content_type="text/markdown",
        keywords="utils",
        packages=find_packages(),
        install_requires=install_requires,
        python_requires=">=3.5, <4",
        entry_points={"console_scripts": ["zconfig = zmazino.config:main"]},
    )
